@@ -1,15 +1,16 @@
  
-/* Radeontool   v1.2
+/* Radeontool   v1.4
  * by Frederick Dean <software@fdd.com>
- * Copyright 2002 Frederick Dean
+ * Copyright 2002-2004 Frederick Dean
  * Use hereby granted under the zlib license.
  *
  * Warning: I do not have the Radeon documents, so this was engineered from 
- * the radeon_reg.h header file.  As such it may break your hardware.
- * Furthermore, this is the "wrong" way to do it.  We should not be poking
- * in a device controlled by another driver.  Very bad.
+ * the radeon_reg.h header file.  
  *
  * USE RADEONTOOL AT YOUR OWN RISK
+ *
+ * Thanks to Deepak Chawla, Erno Kuusela, Rolf Offermanns, and Soos Peter
+ * for patches.
  */
 
 #include <stdio.h>
@@ -176,7 +177,7 @@ void radeon_cmd_light(char *param)
 
     dac_cntl = radeon_get(RADEON_LVDS_GEN_CNTL,"RADEON_LVDS_GEN_CNTL");
     if(param == NULL) {
-        printf("The radeon external DAC looks %s\n",(dac_cntl&(RADEON_LVDS_ON))?"on":"off");
+        printf("The radeon backlight looks %s\n",(dac_cntl&(RADEON_LVDS_ON))?"on":"off");
         exit (-1);
     } else if(strcmp(param,"on") == 0) {
         dac_cntl |= RADEON_LVDS_ON;
